#
# spec file for package python-openapi-schema-validator
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-openapi-schema-validator
Version:        0.6.2
Release:        1.5
Summary:        OpenAPI schema validator for Python
License:        BSD-3-Clause
URL:            https://github.com/p1c2u/openapi-schema-validator
Source:         https://github.com/p1c2u/openapi-schema-validator/archive/%{version}.tar.gz#/openapi-schema-validator-%{version}-gh.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1.0.0}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Provides:       python-openapi_schema_validator = %{version}-%{release}
Requires:       python-jsonschema-specifications >= 2023.5.2
Requires:       python-rfc3339-validator
Requires:       (python-jsonschema >= 4.19.1 with python-jsonschema < 5)
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module jsonschema >= 4.19.1 with %python-jsonschema < 5}
BuildRequires:  %{python_module jsonschema-specifications >= 2023.5.2}
BuildRequires:  %{python_module pytest >= 7}
BuildRequires:  %{python_module rfc3339-validator}
# /SECTION
%python_subpackages

%description
Openapi-schema-validator is a Python library that validates
schema against the OpenAPI Schema Specification v3.0 which
is an extended subset of the JSON Schema Specification
Wright Draft 00.

%prep
%autosetup -p1 -n openapi-schema-validator-%{version}
sed -i 's:tool.pytest.ini_options:hide:' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -k 'not (test_validators)'

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/openapi_schema_validator-%{version}.dist-info
%{python_sitelib}/openapi_schema_validator

%changelog
* Thu Nov  9 2023 ecsos <ecsos@opensuse.org>
- Update to 0.6.2
  * OAS30Validator readonly writeonly fix #135
- Disable test_validators to fix build error.
* Sat Sep 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.6.1
  * Jsonschema package keywords module rename fix #132
* Sat Jul 29 2023 Ben Greiner <code@bnavigator.de>
- Fix requirements
* Tue Jul 25 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.6.0:
  * Compatibility with jsonschema 4.18 #72
  * Python 3.7 support dropped #84
  * OAS30Validator no longer accept read and write properties. Use
    OASReadValidator and OAS30WriteValidator instead. #85
  * Formats raise error for other types fix #67
  * Format validators ignore other types and pass (in accordance with the
    specification)
* Tue Jun 13 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Tue May  9 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.4.4
  * Include tests in sdist archives #71
  * jsonschema 4.17 dependency limit #73
  * add python 3.11 support #74
- Release 0.4.3
  * test required formats only #62
- Release 0.4.2
  * Rely on jsonschema date date-time and uuid format checkers.
    Format checkers assigned to validators #60
  * Backward incompatibility: Missing format checker for format no
    longer raise FormatError
- Release 0.4.1
  * OAS30 read write validators #59
- Release 0.4.0
  * Drop no longer used runtime dependency on attrs #54
  * Re-implemented nullable based on OAS 3.0.3 definition. #57
* Tue Mar 28 2023 pgajdos@suse.com
- python-six is not required
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v0.3.4
  * OASValidator 3.0 read write pass with evolve #52
* Mon Sep  5 2022 John Vandenberg <jayvdb@gmail.com>
- Update to v0.3.3
  * Static types and Mypy static type check
- from v0.3.2
  * type validator error msg formatting fix
- from v0.3.1
  * OpenAPI 3.1 validator's JSONSchema subclassing deprecation fix
  * OpenAPI 3.0 validator's JSONSchema subclassing deprecation workaround
- from v0.3.0
  * OpenAPI 3.1 validator #18
  * drop python 3.6 support #18
  * make jsonschema4 compatible (DeprecationWarning fix) reintroduced
  * 0.2.1 changes
    + Revert "make jsonschema4 compatible (DeprecationWarning fix)"
    + drop python 3.6 support part 2
    + Limit jsonschema dependency
  * Validate oneOf, anyOf and allOf with discriminator OAS30 and OAS31
* Mon Mar 28 2022 pgajdos@suse.com
- version update to 0.2.3
  * readOnly and writeOnly on jsonschema4 fix #41
  * Validate oneOf, anyOf and allOf with discriminator (cherry-pick from 0.3.x) #30
  * Revert "make jsonschema4 compatible (DeprecationWarning fix)" #34
  * Drop python 3.6 support (cherry-pick from 0.3.x and part 2) #35
  * Limit jsonschema dependency #36
  * switch to poetry #27
  * drop python 2.7 and 3.5 support #27 #28
  * make jsonschema4 compatible (DeprecationWarning fix) #25
  * Fix required in composition #16
  * Prevent Schema Mutation #26
  * Stop assigning a version to our Validator (#12)
  * Switch to a MIT-licensed dependency (#4)
  * Pypi license fix (#10)
  * jsonschema dependency fix
  * Permit uppercase characters in UUID (#8)
- python-mock is not required for build
* Tue Mar 31 2020 pgajdos@suse.com
- initial version 0.1.1, required by openapi-core
